.. _dashboard:

*********
Dashboard
*********

The dashboard shows where the user's assets are located and how many different asset types are connected to the platform.
The view serves to quickly identify the status of assets, such as whether there are upcoming opportunities to valorise on flexibility activations.
In particular, the page contains:

.. contents::
    :local:
    :depth: 1


.. image:: https://github.com/SeitaBV/screenshots/raw/main/screenshot_dashboard.png
    :align: center
..    :scale: 40%


.. _dashboard_map:

Interactive map of assets
=========================

The map shows all of the user's assets with icons for each asset type.
Clicking on an asset allows the user to see its current state (e.g. latest measurement of wind power production) and to navigate to the :ref:`analytics` page
to see more details, for instance forecasts.


.. _dashboard_summary:

Summary of asset types
======================

The summary below the map lists all asset types that the user has hooked up to the platform and how many of each there are.
Clicking on the asset type name leads to the :ref:`analytics` page, where data is shown aggregated for that asset type. 

